# Generated by Django 5.0.9 on 2024-11-26 08:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_authorized_keys", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="authorizedkey",
            name="full_name",
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AlterField(
            model_name="authorizedkey",
            name="description",
            field=models.CharField(blank=True, default="", max_length=255),
        ),
        migrations.AlterField(
            model_name="authorizedkey",
            name="public_key",
            field=models.TextField(unique=True),
        ),
        migrations.AlterField(
            model_name="authorizedkey",
            name="username",
            field=models.CharField(max_length=200),
        ),
    ]
